@@ -106,6 +106,14 @@ class GoogleConsoleCredentials(Credentials):
         return user_credentials
 
 
+class FakeCredentials(Credentials):
+    """Fake credentials for use in tests."""
+
+    @property
+    def token(self) -> str:
+        return "fake-token"
+
+
 def authenticate(credentials: Optional[Credentials] = None, use_console: bool = False, use_cache: bool = True) -> None:
     """Authenticates the global client with user credentials.
 
