@@ -4,8 +4,8 @@ import httpx
 
 from myst.auth.credentials import Credentials
 from myst.models.base_model import BaseModel
-from myst.models.exceptions import MystAPIError, MystClientError, UnauthenticatedError
-from myst.models.http_errors import HTTPValidationError
+from myst.models.exceptions import MystAPIError, MystClientError, NotFound, UnauthenticatedError
+from myst.models.http_errors import HTTPValidationError, StringDetailError
 from myst.settings import settings
 from myst.version import get_package_version
 
@@ -14,7 +14,7 @@ ResponseModelType = TypeVar("ResponseModelType", bound=BaseModel)
 
 
 class Client:
-    """HTTP client for interacting with the Myst API."""
+    """HTTP client for interacting with the Myst Platform API."""
 
     API_VERSION = "v1alpha2"
     USER_AGENT_PREFORMAT = "Myst/{api_version} PythonBindings/{package_version}"
@@ -80,7 +80,7 @@ class Client:
             parsed and validated instance of indicated response class
         """
         # Convert the Pydantic request model into JSON form.
-        content = request_model.json() if request_model else None
+        content = request_model.json(exclude_unset=True, by_alias=True) if request_model else None
 
         # Make the API request.
         response = self._client.request(
@@ -97,6 +97,8 @@ class Client:
         elif response.status_code == 422:
             # Special-case 422 validation errors.
             raise MystClientError(HTTPValidationError.parse_raw(response.content))
+        elif response.status_code == 404:
+            raise NotFound(message=StringDetailError.parse_raw(response.content).detail)
         elif 400 <= response.status_code < 500:
             # All other client errors.
             raise MystClientError(response)
@@ -104,3 +106,27 @@ class Client:
             raise MystAPIError(status_code=response.status_code, message="Internal server error")
         else:
             raise NotImplementedError()
+
+
+# Lazily instantiate the global client so that we don't form a connection pool at import time.
+_client: Optional[Client] = None
+
+
+def get_client() -> Client:
+    """Returns the global Myst client instance."""
+    global _client
+
+    if _client is None:
+        _client = Client()
+
+    return _client
+
+
+def set_client(client: Client) -> None:
+    """Sets the global Myst client instance.
+
+    Useful for e.g. configuring timeouts globally.
+    """
+    global _client
+
+    _client = client
