@@ -12,7 +12,6 @@ class BaseModel(pydantic.BaseModel):
     """
 
     class Config:
-        json_encoders = {
-            Time: Time.to_iso_string,
-            TimeDelta: TimeDelta.to_iso_string,
-        }
+        json_encoders = {Time: Time.to_iso_string, TimeDelta: TimeDelta.to_iso_string}
+
+        extra = pydantic.Extra.forbid
