@@ -130,7 +130,6 @@ class TimeDatasetRow(BaseModel):
 
 class TimeDataset(BaseModel):
     object: Literal["TimeDataset"] = Field(
-        "TimeDataset",
         example="TimeDataset",
         description="The field representing the type of object this resource is. Must be `TimeDataset`.",
     )
@@ -217,6 +216,7 @@ class TimeDataset(BaseModel):
         ]
 
         return TimeDataset(
+            object="TimeDataset",
             cell_shape=first_time_array.cell_shape,
             sample_period=first_time_array.sample_period,
             data=time_dataset_rows,
